Hyperiax APIs
================

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   hyperiax.execution
   hyperiax.mcmc
   hyperiax.models
   hyperiax.tree
   hyperiax.plotting

Module contents
---------------

.. automodule:: hyperiax
   :members:
   :undoc-members:
   :show-inheritance:
